@@ -118,8 +118,6 @@ static void record_event_all_consumers(enum ppm_event_type event_type,
 	struct event_data_t *event_datap);
 static int init_ring_buffer(struct ppm_ring_buffer_context *ring);
 static void free_ring_buffer(struct ppm_ring_buffer_context *ring);
-static int ppe_open(struct inode *inode, struct file *filp);
-static ssize_t ppe_write(struct file *filp, const char __user *buf, size_t count, loff_t *f_pos);
 void ppm_task_cputime_adjusted(struct task_struct *p, cputime_t *ut, cputime_t *st);
 
 #ifndef CONFIG_HAVE_SYSCALL_TRACEPOINTS
@@ -148,7 +146,7 @@ static struct ppm_device *g_ppm_devs;
 static struct class *g_ppm_class;
 static unsigned int g_ppm_numdevs;
 static int g_ppm_major;
-bool g_ppe_events_enabled = false;
+bool g_tracers_enabled = false;
 static const struct file_operations g_ppm_fops = {
 	.open = ppm_open,
 	.release = ppm_release,
@@ -157,13 +155,6 @@ static const struct file_operations g_ppm_fops = {
 	.owner = THIS_MODULE,
 };
 
-/* Events file operations */
-static const struct file_operations g_ppe_fops = {
-	.open = ppe_open,
-	.write = ppe_write,
-	.owner = THIS_MODULE,
-};
-
 /*
  * GLOBALS
  */
@@ -171,13 +162,9 @@ LIST_HEAD(g_consumer_list);
 static DEFINE_MUTEX(g_consumer_mutex);
 static bool g_tracepoint_registered;
 
-struct cdev *g_ppe_cdev = NULL;
 #if LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20)
 static struct tracepoint *tp_sys_enter;
 static struct tracepoint *tp_sys_exit;
-struct device *g_ppe_dev = NULL;
-#else
-struct class_device *g_ppe_dev = NULL;
 #endif
 
 static struct tracepoint *tp_sched_process_exit;
@@ -622,8 +609,12 @@ static long ppm_ioctl(struct file *filp, unsigned int cmd, unsigned long arg)
 
 #ifdef for_each_process_thread
 		for_each_process_thread(p, t) {
+#else
+#ifdef for_each_process_all
+		for_each_process_all(p) {
 #else
 		for_each_process(p) {
+#endif
 			t = p;
 			do {
 				task_lock(p);
@@ -646,8 +637,13 @@ static long ppm_ioctl(struct file *filp, unsigned int cmd, unsigned long arg)
 		}
 #else
 				task_unlock(p);
+#ifdef while_each_thread_all
+			} while_each_thread_all(p, t);
+		}
+#else
 			} while_each_thread(p, t);
 		}
+#endif
 #endif
 
 		rcu_read_unlock();
@@ -932,6 +928,13 @@ cleanup_ioctl_procinfo:
 		goto cleanup_ioctl;
 	}
 #endif
+	case PPM_IOCTL_SET_TRACERS_CAPTURE:
+	{
+		vpr_info("PPM_IOCTL_SET_TRACERS_CAPTURE, consumer %p\n", consumer_id);
+		g_tracers_enabled = true;
+		ret = 0;
+		goto cleanup_ioctl;
+	}
 	default:
 		ret = -ENOTTY;
 		goto cleanup_ioctl;
@@ -1106,20 +1109,6 @@ cleanup_mmap:
 	return ret;
 }
 
-/*
- * User events device operations
- */
-static int ppe_open(struct inode *inode, struct file *filp)
-{
-	g_ppe_events_enabled = true;
-	return 0;
-}
-
-static ssize_t ppe_write(struct file *filp, const char __user *buf, size_t count, loff_t *f_pos)
-{
-	return count;
-}
-
 /* Argument list sizes for sys_socketcall */
 #define AL(x) ((x) * sizeof(unsigned long))
 static const unsigned char nas[21] = {
@@ -2117,42 +2106,11 @@ int sysdig_init(void)
 
 	/* create_proc_read_entry(PPM_DEVICE_NAME, 0, NULL, ppm_read_proc, NULL); */
 
-	g_ppe_cdev = cdev_alloc();
-	if (g_ppe_cdev == NULL) {
-		pr_err("error allocating the device %s\n", PROBE_EVENT_DEVICE_NAME);
-		ret = -ENOMEM;
-		goto init_module_err;
-	}
-
-	cdev_init(g_ppe_cdev, &g_ppe_fops);
-
-	if (cdev_add(g_ppe_cdev, MKDEV(g_ppm_major, g_ppm_numdevs), 1) < 0) {
-		pr_err("could not allocate chrdev for %s\n", PROBE_EVENT_DEVICE_NAME);
-		ret = -EFAULT;
-		goto init_module_err;
-	}
-
-#if LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20)
-	g_ppe_dev = device_create(
-#else
-	g_ppe_dev = class_device_create(
-#endif
-			g_ppm_class, NULL,
-			MKDEV(g_ppm_major, g_ppm_numdevs),
-			NULL, /* no additional data */
-			PROBE_EVENT_DEVICE_NAME);
-
-	if (IS_ERR(g_ppe_dev)) {
-		pr_err("error creating the device for %s\n", PROBE_EVENT_DEVICE_NAME);
-		ret = -EFAULT;
-		goto init_module_err;
-	}
-
 	/*
 	 * Snaplen lookahead initialization
 	 */
 	if (dpi_lookahead_init() != PPM_SUCCESS) {
-		pr_err("initializing lookahead-based snaplen  %s\n", PROBE_EVENT_DEVICE_NAME);
+		pr_err("initializing lookahead-based snaplen failed\n");
 		ret = -EFAULT;
 		goto init_module_err;
 	}
@@ -2171,12 +2129,6 @@ int sysdig_init(void)
 	return 0;
 
 init_module_err:
-	if (g_ppe_dev != NULL)
-		device_destroy(g_ppm_class, MKDEV(g_ppm_major, g_ppm_numdevs));
-
-	if (g_ppe_cdev != NULL)
-		cdev_del(g_ppe_cdev);
-
 	for (j = 0; j < n_created_devices; ++j) {
 		device_destroy(g_ppm_class, g_ppm_devs[j].dev);
 		cdev_del(&g_ppm_devs[j].cdev);
@@ -2204,12 +2156,6 @@ void sysdig_exit(void)
 		cdev_del(&g_ppm_devs[j].cdev);
 	}
 
-	if (g_ppe_dev != NULL)
-		device_destroy(g_ppm_class, MKDEV(g_ppm_major, g_ppm_numdevs));
-
-	if (g_ppe_cdev != NULL)
-		cdev_del(g_ppe_cdev);
-
 	if (g_ppm_class)
 		class_destroy(g_ppm_class);
 
