@@ -59,7 +59,7 @@ along with sysdig.  If not, see <http://www.gnu.org/licenses/>.
 #define ppm_access_ok access_ok
 #endif
 
-extern bool g_ppe_events_enabled;
+extern bool g_tracers_enabled;
 
 static void memory_dump(char *p, size_t size)
 {
@@ -187,12 +187,12 @@ inline u32 compute_snaplen(struct event_filler_arguments *args, char *buf, u32 l
 	int peer_address_len;
 	u16 sport, dport;
 
-	if (g_ppe_events_enabled && args->event_type == PPME_SYSCALL_WRITE_X) {
+	if (g_tracers_enabled && args->event_type == PPME_SYSCALL_WRITE_X) {
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 14, 0)
 		struct fd f = fdget(args->fd);
 
-		if (f.file && f.file->f_op) {
-			if (THIS_MODULE == f.file->f_op->owner) {
+		if (f.file && f.file->f_inode) {
+			if (f.file->f_inode->i_rdev == PPM_NULL_RDEV) {
 				res = RW_SNAPLEN_EVENT;
 				fdput(f);
 				return res;
@@ -202,8 +202,16 @@ inline u32 compute_snaplen(struct event_filler_arguments *args, char *buf, u32 l
 		}
 #else
 		struct file* file = fget(args->fd);
-		if (file && file->f_op) {
-			if (THIS_MODULE == file->f_op->owner) {
+		/* Use cached f_inode only on kernel versions that have it
+		 * https://github.com/torvalds/linux/commit/dd37978c50bc8b354e5c4633f69387f16572fdac
+		 */
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 9, 0)
+		if (file && file->f_inode) {
+			if (file->f_inode->i_rdev == PPM_NULL_RDEV) {
+#else
+		if (file && file->f_path.dentry && file->f_path.dentry->d_inode) {
+			if (file->f_path.dentry->d_inode->i_rdev == PPM_NULL_RDEV) {
+#endif
 				res = RW_SNAPLEN_EVENT;
 				fput(file);
 				return res;
